use std::process::Command;
use std::time::Duration;
use std::time::SystemTime;

use crate::action::ACTION_BUILD;
use crate::db::DbHandle;
use crate::db::DbJailAction;

pub(crate) const ACTION_UPDATE_JAIL: &str = "update_jail";
const ACTION_UPDATE_JAIL_INTERVAL: u64 = 604800;

pub(crate) fn update_jail(
    db_conn: &mut DbHandle,
    action: &DbJailAction,
) -> Result<(), Box<dyn std::error::Error>> {
    println!("Updating jail {}.", action.jail_name.as_str());
    Command::new("poudriere")
        .arg("jail")
        .arg("-j")
        .arg(action.jail_name.as_str())
        .arg("-u")
        .status()?
        .exit_ok()?;
    let next_run = (SystemTime::now() + Duration::from_secs(ACTION_UPDATE_JAIL_INTERVAL))
        .duration_since(SystemTime::UNIX_EPOCH)?
        .as_secs();

    let tx = db_conn.conn.transaction()?;
    tx.execute(
        "UPDATE jail_action SET next_run=$1 WHERE name=$2 AND jail_name=$3",
        (next_run, ACTION_UPDATE_JAIL, action.jail_name.as_str()),
    )?;
    // Since we just updated the jail, force a build ASAP since it may need to rebuild everything.
    tx.execute(
        "UPDATE local_action SET next_run=0 WHERE name=$1 AND jail_name=$2",
        (ACTION_BUILD, action.jail_name.as_str()),
    )?;
    tx.commit()?;
    Ok(())
}
